USE [ETLMeta]
GO
/****** Object:  Table [dbo].[Audit]    Script Date: 9/17/2016 8:56:13 PM ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
SET ANSI_PADDING ON
GO
CREATE TABLE [dbo].[Audit](
	[Id] [int] IDENTITY(1,1) NOT NULL,
	[FlowId] [smallint] NOT NULL,
	[StartedAt] [datetime2](0) NOT NULL,
	[EndedAt] [datetime2](0) NULL,
	[PackageGuid] [uniqueidentifier] NOT NULL,
	[PackageName] [varchar](50) NOT NULL,
	[RC_Extracted] [int] NULL,
	[RC_Inserted] [int] NULL,
	[RC_Updated] [int] NULL,
	[RC_Deleted] [int] NULL,
	[RC_FinalCount] [int] NULL,
	[IsSuccess] [bit] NOT NULL,
	[ParentId] [int] NOT NULL,
 CONSTRAINT [PK_Audit] PRIMARY KEY CLUSTERED 
(
	[Id] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO
SET ANSI_PADDING ON
GO
/****** Object:  Table [dbo].[Flows]    Script Date: 9/17/2016 8:56:13 PM ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
SET ANSI_PADDING ON
GO
CREATE TABLE [dbo].[Flows](
	[Id] [smallint] NOT NULL,
	[Name] [varchar](50) NOT NULL,
	[TargetTable] [varchar](128) NULL,
	[SourceSystemId] [tinyint] NOT NULL,
	[IsActive] [bit] NOT NULL,
 CONSTRAINT [PK_Flows] PRIMARY KEY CLUSTERED 
(
	[Id] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO
SET ANSI_PADDING ON
GO
/****** Object:  Table [dbo].[SourceSystems]    Script Date: 9/17/2016 8:56:13 PM ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
SET ANSI_PADDING ON
GO
CREATE TABLE [dbo].[SourceSystems](
	[Id] [tinyint] NOT NULL,
	[Name] [varchar](20) NOT NULL,
	[SystemType] [varchar](30) NOT NULL,
	[Address] [varchar](128) NOT NULL,
	[IsActive] [bit] NOT NULL,
PRIMARY KEY CLUSTERED 
(
	[Id] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON) ON [PRIMARY]
) ON [PRIMARY]

GO
SET ANSI_PADDING ON
GO
ALTER TABLE [dbo].[Audit] ADD  DEFAULT (sysutcdatetime()) FOR [StartedAt]
GO
ALTER TABLE [dbo].[Audit] ADD  DEFAULT ((0)) FOR [IsSuccess]
GO
ALTER TABLE [dbo].[Audit] ADD  DEFAULT ((0)) FOR [ParentId]
GO
ALTER TABLE [dbo].[Flows] ADD  DEFAULT ((1)) FOR [IsActive]
GO
ALTER TABLE [dbo].[SourceSystems] ADD  DEFAULT ((1)) FOR [IsActive]
GO
ALTER TABLE [dbo].[Audit]  WITH CHECK ADD  CONSTRAINT [FK_Audit_2_Flows] FOREIGN KEY([FlowId])
REFERENCES [dbo].[Flows] ([Id])
GO
ALTER TABLE [dbo].[Audit] CHECK CONSTRAINT [FK_Audit_2_Flows]
GO
ALTER TABLE [dbo].[Flows]  WITH CHECK ADD  CONSTRAINT [FK_Flows_2_SourceSystems] FOREIGN KEY([SourceSystemId])
REFERENCES [dbo].[SourceSystems] ([Id])
GO
ALTER TABLE [dbo].[Flows] CHECK CONSTRAINT [FK_Flows_2_SourceSystems]
GO
/****** Object:  StoredProcedure [dbo].[spAuditEnd]    Script Date: 9/17/2016 8:56:13 PM ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE PROCEDURE [dbo].[spAuditEnd]
	@AuditId		INT = 0,
	@RC_Extracted	INT,
	@RC_Inserted	INT,
	@RC_Updated		INT,
	@RC_Deleted		INT,
	@RC_FinalCount	INT
AS

UPDATE dbo.Audit SET
	EndedAt			= SYSUTCDATETIME(),
	RC_Extracted	= @RC_Extracted,
	RC_Inserted		= @RC_Inserted,
	RC_Updated		= @RC_Updated,
	RC_Deleted		= @RC_Deleted,
	RC_FinalCount	= @RC_FinalCount,
	IsSuccess		= 1
WHERE
	1 = 1
	AND Id = @AuditId
;
GO
/****** Object:  StoredProcedure [dbo].[spAuditStart]    Script Date: 9/17/2016 8:56:13 PM ******/
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE PROCEDURE [dbo].[spAuditStart]
	@FlowName		VARCHAR(50),
	@PackageName	VARCHAR(50),
	@PackageGuid	UNIQUEIDENTIFIER
AS

INSERT INTO dbo.Audit (FlowId, PackageName, PackageGuid)
SELECT
	f.Id,
	@PackageName,
	@PackageGuid
FROM dbo.Flows f
WHERE
	1 = 1
	AND f.Name = @FlowName
;

SELECT Id = SCOPE_IDENTITY();
GO
